OccupiedEntry

Struct OccupiedEntry 

pub struct OccupiedEntry<'a, K: 'a + Eq + Hash, V: 'a, S: 'a = RandomState> { /* private fields */ }
A view into an occupied entry in a Cache. It is part of the Entry enum.

Implementations

Source

impl<'a, K: 'a + Eq + Hash, V: 'a, S: 'a + BuildHasher> OccupiedEntry<'a, K, V, S>

pub fn key(&self) -> &K

Gets a reference to the key in the entry.

Examples
use cache_2q::{Cache, Entry};

let mut cache: Cache<&str, u32> = Cache::new(8);
cache.entry("poneyland").or_insert(12);
match cache.entry("poneyland") {
    Entry::Vacant(_) => {
        panic!("Should be occupied");
    },
    Entry::Occupied(occupied) => {
        assert_eq!(occupied.key(), &"poneyland");
    },
}
pub fn get(&self) -> &V

Gets a reference to the value in the entry.

Examples
use cache_2q::{Cache, Entry};

let mut cache: Cache<&str, u32> = Cache::new(8);
cache.entry("poneyland").or_insert(12);

if let Entry::Occupied(o) = cache.entry("poneyland") {
    assert_eq!(o.get(), &12);
} else {
    panic!("Entry should be occupied");
}
pub fn get_mut(&mut self) -> &mut V

Gets a mutable reference to the value in the entry.

Examples
use cache_2q::{Cache, Entry};

let mut cache: Cache<&str, u32> = Cache::new(8);
cache.entry("poneyland").or_insert(12);

assert_eq!(*cache.get("poneyland").unwrap(), 12);
if let Entry::Occupied(mut o) = cache.entry("poneyland") {
     *o.get_mut() += 10;
} else {
    panic!("Entry should be occupied");
}

assert_eq!(*cache.get("poneyland").unwrap(), 22);
pub fn into_mut(self) -> &'a mut V

Converts the OccupiedEntry into a mutable reference to the value in the entry with a lifetime bound to the cache itself.

Examples
use cache_2q::{Cache, Entry};

let mut cache: Cache<&str, u32> = Cache::new(8);
cache.entry("poneyland").or_insert(12);

assert_eq!(*cache.get("poneyland").unwrap(), 12);
if let Entry::Occupied(o) = cache.entry("poneyland") {
    *o.into_mut() += 10;
} else {
    panic!("Entry should be occupied");
}

assert_eq!(*cache.get("poneyland").unwrap(), 22);
pub fn insert(&mut self, value: V) -> V

Sets the value of the entry, and returns the entry’s old value.

Examples
use cache_2q::{Cache, Entry};

let mut cache: Cache<&str, u32> = Cache::new(8);
cache.entry("poneyland").or_insert(12);

if let Entry::Occupied(mut o) = cache.entry("poneyland") {
    assert_eq!(o.insert(15), 12);
} else {
    panic!("Entry should be occupied");
}

assert_eq!(*cache.get("poneyland").unwrap(), 15);
pub fn remove(self) -> V

Takes the value out of the entry, and returns it.

Examples
use cache_2q::{Cache, Entry};

let mut cache: Cache<&str, u32> = Cache::new(8);
cache.entry("poneyland").or_insert(12);

if let Entry::Occupied(o) = cache.entry("poneyland") {
    assert_eq!(o.remove(), 12);
} else {
    panic!("Entry should be occupied");
}

assert_eq!(cache.contains_key("poneyland"), false);